@@ -1,9 +1,12 @@
 from typing import Dict
 from dataclasses import dataclass, field
 
-from anastasia_logging.codes.standard_errors import _STANDARD_ERROR_CODES
-from anastasia_logging.codes.standard_warning import _STANDARD_WARNING_CODES
+from anastasia_logging.codes.standard_debug import _STANDARD_DEBUG_CODES
 from anastasia_logging.codes.standard_info import _STANDARD_INFO_CODES
+from anastasia_logging.codes.standard_warning import _STANDARD_WARNING_CODES
+from anastasia_logging.codes.standard_errors import _STANDARD_ERROR_CODES
+from anastasia_logging.codes.standard_critical import _STANDARD_CRITICAL_CODES
+
 
 @dataclass
 class StandardCodes:
@@ -24,6 +27,8 @@ class StandardCodes:
 
     """
 
-    ERROR: Dict[int, str] = field(default_factory=lambda: _STANDARD_ERROR_CODES)
+    DEBUG: Dict[int, str] = field(default_factory=lambda: _STANDARD_DEBUG_CODES)
+    INFO: Dict[int, str] = field(default_factory=lambda: _STANDARD_INFO_CODES)
     WARNING: Dict[int, str] = field(default_factory=lambda: _STANDARD_WARNING_CODES)
-    INFO: Dict[int, str] = field(default_factory=lambda: _STANDARD_INFO_CODES)
\ No newline at end of file
+    ERROR: Dict[int, str] = field(default_factory=lambda: _STANDARD_ERROR_CODES)
+    CRITICAL: Dict[int, str] = field(default_factory=lambda: _STANDARD_CRITICAL_CODES)
\ No newline at end of file
